@@ -41,3 +41,20 @@
 #  define FLINT_DLL __declspec(dllimport)
 # endif
 #endif
+
+#define DIAGNOSTIC_PUSH
+#define DIAGNOSTIC_POP
+#define DIAGNOSTIC_IGNORE_INCOMPATIBLE_FUNCTION_POINTER_TYPES
+#define DIAGNOSTIC_IGNORE_DISCARDED_QUALIFIERS
+#define DIAGNOSTIC_IGNORE_FORMAT
+#define DIAGNOSTIC_IGNORE_DANGLING_POINTER
+#define DIAGNOSTIC_IGNORE_CAST_FUNCTION_TYPE
+#define DIAGNOSTIC_IGNORE_OVERLENGTH_STRINGS
+#define DIAGNOSTIC_IGNORE_UNUSED_VARIABLE
+#define DIAGNOSTIC_IGNORE_MAYBE_UNINITIALIZED
+
+#define PUSH_OPTIONS
+#define POP_OPTIONS
+#define OPTIMIZE_O2
+#define OPTIMIZE_OSIZE
+#define OPTIMIZE_UNROLL_LOOPS
